<?php

namespace Drupal\taxonomy_entity\Form;

use Drupal\Core\Render\Element;
use Drupal\taxonomy\Form\OverviewTerms as CoreOverviewTerms;
use Drupal\Core\Form\FormStateInterface;
use Drupal\taxonomy\VocabularyInterface;

/**
 * Provides terms overview form for a taxonomy vocabulary.
 */
class OverviewTerms extends CoreOverviewTerms {

  /**
   * Form constructor.
   *
   * Display a tree of all the terms in a vocabulary, with options to edit
   * each one. The form is made drag and drop by the theme function.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   * @param \Drupal\taxonomy\VocabularyInterface $taxonomy_vocabulary
   *   The vocabulary to display the overview form for.
   *
   * @return array
   *   The form structure.
   */
  public function buildForm(array $form, FormStateInterface $form_state, VocabularyInterface $taxonomy_vocabulary = NULL) {
    $form = parent::buildForm($form, $form_state, $taxonomy_vocabulary);

    $hierarchy = $taxonomy_vocabulary->getHierarchy();
    if ($hierarchy === VocabularyInterface::HIERARCHY_DISABLED) {
      $tabledrags = $form['terms']['#tabledrag'];
      foreach ($tabledrags as $key => $tabledrag) {
        if ($tabledrag['relationship'] == 'parent' || $tabledrag['relationship'] == 'group') {
          unset($form['terms']['#tabledrag'][$key]);
        }
      }
      if (($key = array_search('taxonomy/drupal.taxonomy', $form['terms']['#attached']['library'])) !== FALSE) {
        unset($form['terms']['#attached']['library'][$key]);
      }
      unset($form['terms']['#attached']['drupalSettings']['taxonomy']);
    }

    return $form;
  }

}
